@@ -1,5 +1,5 @@
 package Net::Stripe;
-$Net::Stripe::VERSION = '0.34';
+$Net::Stripe::VERSION = '0.35';
 use Moose;
 use Class::Load;
 use Kavorka;
@@ -43,7 +43,8 @@ Charges: {
                        HashRef :$metadata?,
                        Bool :$capture?,
                        Str :$statement_description?,
-                       Int :$application_fee?
+                       Int :$application_fee?,
+                       Str :$receipt_email?
                      ) {
         my $charge = Net::Stripe::Charge->new(amount => $amount,
                                               currency => $currency,
@@ -53,7 +54,8 @@ Charges: {
                                               metadata => $metadata,
                                               capture => $capture,
                                               statement_description => $statement_description,
-                                              application_fee => $application_fee
+                                              application_fee => $application_fee,
+                                              receipt_email => $receipt_email
                                           );
         return $self->_post('charges', $charge);
     }
@@ -172,12 +174,13 @@ Customers: {
         $self->_delete("customers/$customer");
     }
 
-    method get_customers(HashRef :$created?, Str :$ending_before?, Int :$limit?, Str :$starting_after?) {
+    method get_customers(HashRef :$created?, Str :$ending_before?, Int :$limit?, Str :$starting_after?, Str :$email?) {
         $self->_get_collections('customers',
                                 created => $created,
                                 ending_before => $ending_before,
                                 limit => $limit,
-                                starting_after => $starting_after
+                                starting_after => $starting_after,
+                                email => $email,
                             );
     }
 }
@@ -210,10 +213,16 @@ Cards: {
     }
 
     method post_card(Net::Stripe::Customer|Str :$customer,
-                     HashRef|Net::Stripe::Card :$card) {
+                     HashRef|Net::Stripe::Card|Net::Stripe::Token|Str :$card) {
         if (ref($customer)) {
             $customer = $customer->id;
         }
+        if (! ref($card) && $card =~ /^tok_.+/) {
+            return $self->_post("customers/$customer/cards", {card=> $card});
+        }
+        if (ref($card) eq 'Net::Stripe::Token' && $card->id) {
+            return $self->_post("customers/$customer/cards", {card=> $card->id});
+        }
         # Update the card.
         if (ref($card) eq 'Net::Stripe::Card' && $card->id) {
             return $self->_post("customers/$customer/cards", $card);
@@ -598,9 +607,15 @@ sub _get_collections {
     if (my $c = $args{object}) {
         push @path_args, "object=$c";
     }
+    if (my $c = $args{ending_before}) {
+        push @path_args, "ending_before=$c";
+    }
     if (my $c = $args{starting_after}) {
         push @path_args, "starting_after=$c";
     }
+    if (my $e = $args{email}) {
+        push @path_args, "email=$e";
+    }
 
     # example: $Stripe->get_charges( 'count' => 100, 'created' => { 'gte' => 1397663381 } );
     if (defined($args{created})) {
@@ -739,7 +754,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -884,6 +899,8 @@ L<https://stripe.com/docs/api#create_charge>
 
 =item * application_fee - Int - optional
 
+=item * receipt_email - Str - The email address to send this charge's receipt to - optional
+
 =back
 
 Returns L<Net::Stripe::Charge>.
@@ -1754,6 +1771,10 @@ Sherrard Burton <32931314+sherrardb@users.noreply.github.com>
 
 =item *
 
+Sherrard Burton <sburton@allafrica.com>
+
+=item *
+
 Slobodan Mišković <slobodan@miskovic.ca>
 
 =item *
