@@ -1,7 +1,6 @@
 package Net::Stripe::Card;
-$Net::Stripe::Card::VERSION = '0.34';
+$Net::Stripe::Card::VERSION = '0.35';
 use Moose;
-use Moose::Util::TypeConstraints qw(union);
 use Kavorka;
 use Net::Stripe::Token;
 
@@ -14,8 +13,10 @@ has 'name'            => (is => 'ro', isa => 'Maybe[Str]');
 has 'address_line1'   => (is => 'ro', isa => 'Maybe[Str]');
 has 'address_line2'   => (is => 'ro', isa => 'Maybe[Str]');
 has 'address_zip'     => (is => 'ro', isa => 'Maybe[Str]');
+has 'address_city'    => (is => 'ro', isa => 'Maybe[Str]');
 has 'address_state'   => (is => 'ro', isa => 'Maybe[Str]');
 has 'address_country' => (is => 'ro', isa => 'Maybe[Str]');
+has 'metadata'        => (is => 'rw', isa => 'Maybe[HashRef]');
 
 # Both input and output
 has 'exp_month'       => (is => 'ro', isa => 'Maybe[Int]', required => 1);
@@ -31,12 +32,23 @@ has 'fingerprint'          => (is => 'ro', isa => 'Maybe[Str]');
 has 'last4'                => (is => 'ro', isa => 'Maybe[Str]');
 has 'brand'                => (is => 'ro', isa => 'Maybe[Str]');  # formerly 'type'
 
+method form_fields_for_card_metadata {
+    my $metadata = $self->metadata();
+    my @metadata = ();
+    while( my($k,$v) = each(%$metadata) ) {
+      push @metadata, 'card[metadata]['.$k.']';
+      push @metadata, $v;
+    }
+    return @metadata;
+}
+
 method form_fields {
     return (
+        $self->form_fields_for_card_metadata(),
         map { ("card[$_]" => $self->$_) }
             grep { defined $self->$_ }
                 qw/number cvc name address_line1 address_line2 address_zip
-                   address_state address_country exp_month exp_year/
+                   address_city address_state address_country exp_month exp_year/
     );
 }
 
@@ -53,7 +65,7 @@ Net::Stripe::Card - represent a Card object from Stripe
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 ATTRIBUTES
 
