@@ -1,5 +1,5 @@
 package Net::Stripe::Charge;
-$Net::Stripe::Charge::VERSION = '0.34';
+$Net::Stripe::Charge::VERSION = '0.35';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -24,6 +24,7 @@ has 'failure_code'        => (is => 'ro', isa => 'Maybe[Str]');
 has 'application_fee'     => (is => 'ro', isa => 'Maybe[Int]');
 has 'metadata'            => (is => 'rw', isa => 'Maybe[HashRef]');
 has 'invoice'             => (is => 'ro', isa => 'Maybe[Str]');
+has 'receipt_email'       => (is => 'ro', isa => 'Maybe[Str]');
 
 method form_fields {
     return (
@@ -31,7 +32,7 @@ method form_fields {
         $self->form_fields_for_metadata(),
         map { $_ => $self->$_ }
             grep { defined $self->$_ }
-                qw/amount currency customer description application_fee/
+                qw/amount currency customer description application_fee receipt_email/
     );
 }
 
@@ -48,7 +49,7 @@ Net::Stripe::Charge - represent an Charge object from Stripe
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 ATTRIBUTES
 
