@@ -1,7 +1,7 @@
 package Net::Stripe::Plan;
-$Net::Stripe::Plan::VERSION = '0.34';
+$Net::Stripe::Plan::VERSION = '0.35';
 use Moose;
-use Moose::Util::TypeConstraints;
+use Moose::Util::TypeConstraints qw(subtype as where message);
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -42,7 +42,7 @@ Net::Stripe::Plan - represent a Plan object from Stripe
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 ATTRIBUTES
 
